"""URLs for the time_out app."""
# from django.conf.urls.defaults import patterns, url

# from . import views


# urlpatterns = patterns(
#     '',
#     url(r'^$',
#         views.YourView.as_view(),
#         name='time_out_default'),
# )



# Django/Python imports
from datetime import datetime
from django.shortcuts import render_to_response

# App imports
from .models import MaintenanceSchedule


def get_current_time():
    """
    Determine what the current time.
    :return: Time data object.
    """
    return datetime.now()


class DownTimeMiddleware(object):


    def process_request(self, request):
        """
        Hook: process_request()
        Called on each request, before Django decides which view to execute.
        :param request:
        :return:
        """
        # If the admin then don't show maintenance page.
        if request.path.startswith("/admin"):
            return None

        # Filter all objects
        now = get_current_time()
        objects = MaintenanceSchedule.objects.filter(start_time__lt=now, end_time__gt=now, active=True)

        if objects.count() > 0:
            # If we have more than one.
            maintenance = objects[0]

            abort_request = True

            if abort_request:
                context = {'maintenance': maintenance}
                return render_to_response('down_time/down_time.html', context)

        return None































"""Tests for the models of the time_out app."""
from django.test import TestCase

# from .factories import YourModelFactory


class DummyTestCase(TestCase):
    """Sample test case to show that `python setup.py test` works."""
    def test_something(self):
        self.assertTrue(True)



from django.db import models


class MaintenanceSchedule(models.Model):
    """
     Maintenance Schedule Of All Tasks.
    """
    description = models.TextField(max_length=60,
                                   help_text='Short description of the maintenance work to be carried out.')
    start_time = models.DateTimeField(help_text='Date and time of planned work.')
    end_time = models.DateTimeField(help_text='Completion date and time of planned work.')
    active = models.BooleanField(default=False, help_text='Is task active, should it run?')

    def __unicode__(self):
        return self.start_time.isoformat()




"""Admin classes for the time_out app."""

# Django/Python imports.
from django.contrib import admin

# App imports
from .models import MaintenanceSchedule


class MaintenanceScheduleAdmin(admin.ModelAdmin):
    """
    Attributes admin overrides.
    """
    list_display = ['start_time', 'end_time', 'active']
    search_fields = ['start_time', 'end_time', 'description']
    sortable_field_name = "start_time"


admin.site.register(MaintenanceSchedule, MaintenanceScheduleAdmin)
